"""Exceptions for ``clinvar-tsv``."""


class ClinvarTsvException(Exception):  # pragma: no cover
    """Exception raised by ``clinvar-tsv``"""


class XmlParseException(Exception):  # pragma: no cover
    """Raised on problems parsing the XML"""


class NoSequenceLocation(Exception):  # pragma: no cover
    """Raised on problems parsing the XML"""
